###  Quollio Intelligence Agent Support For Databricks
Notable Files:
1. [quollio_lineage_table_level.sql](models/quollio_lineage_table_level.sql) - Generates table lineage data from Databricks system tables.
2. [quollio_lineage_column_level.sql](models/quollio_lineage_table_level.sql) - Generates column lineage data from Databricks system tables.
3. [sources.yml](models/sources.yml) - Refrences sources in the Databricks system catalog.